<?php

namespace Ingot\Tests;

use Ingot\Tests\Fixtures\app\Application;

class ApplicationTest extends \PHPUnit_Framework_TestCase
{
    /**
     * @test
     */
    function it_loads_application_with_env_and_pco_file()
    {
        $app = new Application(__DIR__ . '/Fixtures/app', 'dev', false);
        $app->boot();

        $this->assertTrue($app['dev']);
        $this->assertEquals('dev', $app['env']);
        $this->assertEquals('/some/path', $app['pco_expanded']);
    }
}
